@@ -1,5 +1,4 @@
-from .constants import DISTRICTS, PROVINCES, CONSTITUENCIES
-
+from .constants import DISTRICTS, PROVINCES, CONSTITUENCIES, TOWNS, WARDS
 
 # function to return available provinces
 def get_provinces() -> list:
@@ -36,4 +35,13 @@ def get_all_constituencies(limit: int = 10) -> list:
     return all_constituencies[:limit]
 
 
-print(get_all_districts(200000))
+# function to retrieve all towns based on district.
+def get_towns(district: str) -> list:
+    return TOWNS.get(district)
+
+
+# function to retrieve all wards based on district.
+def get_wards(district: str) -> list:
+    return WARDS.get(district)
+
+print(get_wards('Lusaka'))
\ No newline at end of file
